/* ------------------------------------------------------------------ 

	Title: BREditWindow

	Description:  Edits resource name and ID

	Author :
		Stephen Wardlaw, M.D.
		Medical R&D
		Highrock
		Lyme, CT 06371

	Edit History:	
		05 September, 1999
			Created
------------------------------------------------------------------ */ 
#include "BREditWindow.h"

#include "U_Conversions.h"
#include <InterfaceKit.h>
#include <AppKit.h>
#include <stdio.h>

// -------------------------------------------------------------------
//	* CONSTRUCTOR
// -------------------------------------------------------------------
BREditWindow::BREditWindow(const char* wName,
						   BRect frame,
						   const char* name,
						   window_look look,
						   window_feel feel,
						   uint32 flags
						   ):BWindow(frame,name,look,feel,flags)
{
	BMessage* theMesg = new BMessage(add_bmp);
	
	// Set up the controls, they will be sized later.
	BRect frame(0,0,0,0);
	
	// The "OK" button
	BButton* theButton = new BButton(frame,NULL,"OK",theMesg,B_FOLLOW_NONE);
	theButton->SetTarget(this);
	theButton->ResizeToPreferred();
	float bWidth;
	float bHeight;
	theButton->GetPreferredSize(&bWidth,&bHeight);
	
	// The name editor
	mEditName = new BTextControl(frame,"EName","Res.Name",wName,B_FOLLOW_NONE);
	mEditName->TextView()->SetMaxBytes(max_res_name);
	mEditName->ResizeToPreferred();
	float nWidth;
	float nHeight;
	mEditName->GetPreferredSize(&nWidth,&nHeight);
	
	// The ID editor
	mEditID = new BTextControl(frame,"EID","Res.ID","0",B_FOLLOW_NONE);
	mEditID->TextView()->SetMaxBytes(max_res_id);
	float iWidth;
	float iHeight;
	mEditID->ResizeToPreferred();
	mEditID->GetPreferredSize(&iWidth,&iHeight);
	
	// Make everything fit
	const float view_marg = 5;
	const float view_wd = 250;
	float vHt = view_marg*3 + nHeight + bHeight;
	float vWd = view_wd > nWidth ? view_wd : nWidth;
	mEditID->ResizeTo(vWd,nHeight);
	vWd += view_marg*2;
	ResizeTo(vWd,vHt);
	MoveTo(100,100);
	BRect vFrame(0,0,vWd,vHt);
	BView* theView = new BView(vFrame,NULL,B_FOLLOW_ALL,B_WILL_DRAW);
	const rgb_color vColor = {209,209,209};
	theView->SetViewColor(vColor);
	AddChild(theView);
	theView->AddChild(mEditName);
	theView->AddChild(mEditID);
	theView->AddChild(theButton);
	mEditName->MoveTo(view_marg,view_marg);
	theButton->MoveTo(vWd - (bWidth + view_marg), vHt - (bHeight + view_marg));
	float vPosn = mEditName->Frame().bottom;
	vPosn += ((Bounds().bottom - view_marg) - vPosn)/2; 
	mEditID->MoveTo(view_marg,vPosn);
	Show();
}
		
BREditWindow::~BREditWindow()
{
}		
// -------------------------------------------------------------------
//	* Public Methods
// -------------------------------------------------------------------
void
BREditWindow::MessageReceived(BMessage* theMesg)
{
	switch (theMesg->what) {
	
		case add_bmp :
			theMesg->AddString(res_name_str,mEditName->Text());
			theMesg->AddInt32(res_id_str,::AlphaToLong(mEditID->Text()));
			be_app->PostMessage(theMesg);
			Quit();
			break;
			
		default:
			BWindow::MessageReceived(theMesg);
	}
}
// -------------------------------------------------------------------
//	* Protected Methods
// -------------------------------------------------------------------
// -------------------------------------------------------------------
